@@ -447,6 +447,7 @@ class DisqusService(object):
             anonymous_author=self._decode_anonymous_author(dct.get("anonymous_author")),
             author=self._decode_author(dct.get("author")),
             has_been_moderated=dct.get("has_been_moderated"),
+            ip_address=dct.get("ip_address"),
         )
 
     def _decode_author(self, dct):
@@ -638,7 +639,8 @@ class Post(object):
                  is_anonymous=False,
                  anonymous_author=None,
                  author=None,
-                 has_been_moderated=False):
+                 has_been_moderated=False,
+                 ip_address=None):
         """
         id: a unique alphanumeric string identifying this Post object.
         forum: the id for the forum this post belongs to.
@@ -669,6 +671,7 @@ class Post(object):
             self.author = author
             self.anonymous_author = None
         self.has_been_moderated = has_been_moderated
+        self.ip_address = ip_address
     
     def _get_parent_post(self):
         if self._parent_post_id and self._parent_post is None:
